@@ -13,12 +13,22 @@ print.local_fit <- function(x, ...) {
   }
 
   if (x$method == "pls") {
-    cat("Partial least squares (pls)")
+    if (x$modified) {
+      mss <- "Modified partial least squares (mpls)"
+    } else {
+      mss <- "Partial least squares (pls)"
+    }
+    cat(mss)
     cat("\nNumber of factors:", x$pls_c)
   }
 
   if (x$method == "wapls") {
-    cat("Weighted average partial least squares (wapls)")
+    if (x$modified) {
+      mss <- "Weighted average modified partial least squares (wampls)"
+    } else {
+      mss <- "Weighted average partial least squares (wapls)"
+    }
+    cat(mss)
     cat("\nMin. and max. number of factors: from", x$pls_c[["min_pls_c"]], "to", x$pls_c[["max_pls_c"]])
   }
 
